/*
 * This software is governed by the CeCILL-B license under French law and
 * abiding by the rules of distribution of free software. You can use, modify
 * and/ or redistribute the software under the terms of the CeCILL-B license as
 * circulated by CEA, CNRS and INRIA at the following URL "http://www.cecill.info".
 * 
 * As a counterpart to the access to the source code and rights to copy, modify
 * and redistribute granted by the license, users are provided only with a
 * limited warranty and the software's author, the holder of the economic
 * rights, and the successive licensors have only limited liability.
 * 
 * In this respect, the user's attention is drawn to the risks associated with
 * loading, using, modifying and/or developing or reproducing the software by
 * the user in light of its specific status of free software, that may mean that
 * it is complicated to manipulate, and that also therefore means that it is
 * reserved for developers and experienced professionals having in-depth
 * computer knowledge. Users are therefore encouraged to load and test the
 * software's suitability as regards their requirements in conditions enabling
 * the security of their systems and/or data to be ensured and, more generally,
 * to use and operate it in the same conditions as regards security.
 * 
 * The fact that you are presently reading this means that you have had
 * knowledge of the CeCILL-B license and that you accept its terms.
 */
package fr.amap.commons.util.debug;

import java.awt.Component;
import javax.swing.JOptionPane;
import org.apache.log4j.BasicConfigurator;
import org.apache.log4j.Level;
import org.apache.log4j.Logger;

/**
 * Perform a global centralized debugging / logging system for the entire project.
 * @author Tristan Muller (tristan.muller@cirad.fr)
 */
public final class Debugger {
    
    private static final Logger LOGGER = Logger.getLogger(Debugger.class);
    
    /**
     * Print an exception in a message dialog and in the terminal
     * @param message The message object to print.
     * @param level The warning level of the message.
     * @param parent The modal parent of the window.
     */
    public static final void debugInterface(final Object message, 
            final DebugLevel level, final Component parent) {
        /* Get the JOptionPane message type */
        int messageType = JOptionPane.INFORMATION_MESSAGE;
        
        switch(level) {
            case INFOS: 
                messageType = JOptionPane.INFORMATION_MESSAGE;
                break;
            case WARNING:
                messageType = JOptionPane.WARNING_MESSAGE;
                break;
            case ERROR:
                messageType = JOptionPane.ERROR_MESSAGE;
                break;
        }
        
        /* Print the message in a message dialog */
        JOptionPane.showMessageDialog(parent, message, level.name(), messageType);
        
        /* Print the message in the terminal */
        debugTerminal(message, level);
    }
    
    /**
     * Print an exception in the terminal.
     * @param message The message object to print.
     * @param level The warning level of the message.
     */
    public static final void debugTerminal(final Object message, 
            final DebugLevel level) {    
        /* Initialize Log4j */
        BasicConfigurator.configure();
        
        /* Get the Log4j level */
        Level priority = Level.INFO;
        
        switch(level) {
            case INFOS: 
                priority = Level.INFO;
                break;
            case WARNING:
                priority = Level.WARN;
                break;
            case ERROR:
                priority = Level.ERROR;
                break;
        }
        
        /* print the exception in the terminal */
        if (message instanceof Throwable) {
            LOGGER.log(priority, level.name(), (Throwable) message);
            ((Throwable) message).printStackTrace();
        } else {
            LOGGER.log(priority, level.name() + " " + message, null);
        }
    }
    
}
